@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2014  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -18,6 +18,16 @@
 */
 
 
+/**
+   \file libcw_console.c
+
+   \brief Console buzzer audio sink.
+*/
+
+
+
+
+
 #include "config.h"
 
 
@@ -59,6 +69,8 @@
 
 #include "libcw_console.h"
 #include "libcw_debug.h"
+#include "libcw_utils.h"
+#include "libcw_gen.h"
 
 
 extern cw_debug_t cw_debug_object;
@@ -138,7 +150,7 @@ bool cw_is_console_possible(const char *device)
    the client code must use cw_is_console_possible() instead, prior
    to calling this function.
 
-   You must use cw_generator_set_audio_device_internal() before calling
+   You must use cw_gen_set_audio_device_internal() before calling
    this function. Otherwise generator \p gen won't know which device to open.
 
    \param gen - current generator
@@ -289,6 +301,8 @@ int cw_console_write_low_level_internal(cw_gen_t *gen, bool state)
 		local_state = state;
 	}
 
+	/* TODO: take a look at KDMKTONE ioctl argument. */
+
 	/* Calculate the correct argument for KIOCSOUND.  There's nothing we
 	   can do to control the volume, but if we find the volume is set to
 	   zero, the one thing we can do is to just turn off tones.  A bit
@@ -320,7 +334,7 @@ int cw_console_configure(cw_gen_t *gen, const char *device)
 	assert (gen);
 
 	gen->audio_system = CW_AUDIO_CONSOLE;
-	cw_generator_set_audio_device_internal(gen, device);
+	cw_gen_set_audio_device_internal(gen, device);
 
 	gen->open_device  = cw_console_open_device_internal;
 	gen->close_device = cw_console_close_device_internal;
