@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2014  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,6 +32,8 @@ extern "C"
 {
 #endif
 
+#include <stdint.h> /* uint32_t */
+
 
 #define CW_DEBUG_N_EVENTS_MAX (1024 * 128)
 
@@ -158,7 +160,7 @@ enum {
 
 
 
-#if CW_DEV_RAW_SINK
+#ifdef LIBCW_WITH_DEV
 int  cw_dev_debug_raw_sink_write_internal(cw_gen_t *gen);
 void cw_dev_debug_print_generator_setup(cw_gen_t *gen);
 #endif
@@ -167,6 +169,14 @@ void cw_dev_debug_print_generator_setup(cw_gen_t *gen);
 
 
 
+#ifdef LIBCW_UNIT_TESTS
+unsigned int test_cw_debug_flags_internal(void);
+#endif /* #ifdef LIBCW_UNIT_TESTS */
+
+
+
+
+
 #if defined(__cplusplus)
 }
 #endif
